# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["EmployeeLinkUserParams"]


class EmployeeLinkUserParams(TypedDict, total=False):
    employee_id: Required[Annotated[str, PropertyInfo(alias="employeeId")]]

    user_id: Required[Annotated[str, PropertyInfo(alias="userId")]]

    role: SequenceNotStr[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EmployerCreateResponse"]


class EmployerCreateResponse(BaseModel):
    api_id: str = FieldInfo(alias="_id")

    address: Dict[str, object]

    email: str

    name: str

    phones: List[Dict[str, object]]

    created_at: Optional[str] = FieldInfo(alias="createdAt", default=None)

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)

    demo: Optional[bool] = None

    employee_consent: Optional[bool] = FieldInfo(alias="employeeConsent", default=None)

    onsite_clinic: Optional[bool] = FieldInfo(alias="onsiteClinic", default=None)

    website: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .service_bundle_create_params import ServiceBundleCreateParams as ServiceBundleCreateParams
from .service_bundle_list_response import ServiceBundleListResponse as ServiceBundleListResponse
from .service_bundle_update_params import ServiceBundleUpdateParams as ServiceBundleUpdateParams
from .service_bundle_create_response import ServiceBundleCreateResponse as ServiceBundleCreateResponse
from .service_bundle_update_response import ServiceBundleUpdateResponse as ServiceBundleUpdateResponse
from .service_bundle_retrieve_response import ServiceBundleRetrieveResponse as ServiceBundleRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["EmployeeUpdateParams", "Address", "ExtendedField", "Phone"]


class EmployeeUpdateParams(TypedDict, total=False):
    _id: Required[str]

    active_account: Annotated[Literal["Active", "Inactive"], PropertyInfo(alias="activeAccount")]

    address: Address

    blurb: str

    departments: SequenceNotStr[str]

    dob: str

    email: str

    employer_id: str

    extended_fields: Annotated[Iterable[ExtendedField], PropertyInfo(alias="extendedFields")]

    first_name: Annotated[str, PropertyInfo(alias="firstName")]

    last_name: Annotated[str, PropertyInfo(alias="lastName")]

    phone: Iterable[Phone]

    title: str


class Address(TypedDict, total=False):
    city: Required[str]

    postal_code: Required[Annotated[str, PropertyInfo(alias="postalCode")]]

    state: Required[str]

    street1: Required[str]

    country: str

    county: str

    street2: str


class ExtendedField(TypedDict, total=False):
    name: Required[str]

    value: Required[str]


class Phone(TypedDict, total=False):
    number: Required[str]

    type: Required[Literal["Cell", "Home", "Work", "Other"]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import hl7_send_results_params
from .._types import Body, Query, Headers, NotGiven, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["Hl7Resource", "AsyncHl7Resource"]


class Hl7Resource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> Hl7ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return Hl7ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> Hl7ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return Hl7ResourceWithStreamingResponse(self)

    def send_results(
        self,
        *,
        employee_id: str,
        file: hl7_send_results_params.File,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> str:
        """
        Send lab results or documents via HL7

        Args:
          employee_id: Employee ID to send results for

          file: File containing the results

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/hl7/results",
            body=maybe_transform(
                {
                    "employee_id": employee_id,
                    "file": file,
                },
                hl7_send_results_params.Hl7SendResultsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )


class AsyncHl7Resource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncHl7ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncHl7ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncHl7ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return AsyncHl7ResourceWithStreamingResponse(self)

    async def send_results(
        self,
        *,
        employee_id: str,
        file: hl7_send_results_params.File,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> str:
        """
        Send lab results or documents via HL7

        Args:
          employee_id: Employee ID to send results for

          file: File containing the results

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/hl7/results",
            body=await async_maybe_transform(
                {
                    "employee_id": employee_id,
                    "file": file,
                },
                hl7_send_results_params.Hl7SendResultsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )


class Hl7ResourceWithRawResponse:
    def __init__(self, hl7: Hl7Resource) -> None:
        self._hl7 = hl7

        self.send_results = to_raw_response_wrapper(
            hl7.send_results,
        )


class AsyncHl7ResourceWithRawResponse:
    def __init__(self, hl7: AsyncHl7Resource) -> None:
        self._hl7 = hl7

        self.send_results = async_to_raw_response_wrapper(
            hl7.send_results,
        )


class Hl7ResourceWithStreamingResponse:
    def __init__(self, hl7: Hl7Resource) -> None:
        self._hl7 = hl7

        self.send_results = to_streamed_response_wrapper(
            hl7.send_results,
        )


class AsyncHl7ResourceWithStreamingResponse:
    def __init__(self, hl7: AsyncHl7Resource) -> None:
        self._hl7 = hl7

        self.send_results = async_to_streamed_response_wrapper(
            hl7.send_results,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = [
    "OrderCreateParams",
    "Variant0",
    "Variant0Person",
    "Variant0Service",
    "Variant0ProvidersID",
    "Variant1",
    "Variant1Service",
    "Variant1Person",
    "Variant1ProvidersID",
    "Variant2",
    "Variant2ProvidersID",
    "Variant2Person",
    "Variant2Service",
    "Variant3",
    "Variant3ProvidersID",
    "Variant3Person",
    "Variant3Service",
]


class Variant0(TypedDict, total=False):
    payment_method: Required[Annotated[Literal["self-pay", "employer-sponsored"], PropertyInfo(alias="paymentMethod")]]

    person: Required[Variant0Person]

    provider_id: Required[Annotated[str, PropertyInfo(alias="providerId")]]

    services: Required[Iterable[Variant0Service]]

    _id: str

    brand_id: Annotated[str, PropertyInfo(alias="brandId")]

    due_date: Annotated[Union[str, datetime], PropertyInfo(alias="dueDate", format="iso8601")]

    due_dates: Annotated[SequenceNotStr[Union[str, datetime]], PropertyInfo(alias="dueDates", format="iso8601")]

    employee_id: Annotated[str, PropertyInfo(alias="employeeId")]

    employee_ids: Annotated[SequenceNotStr[str], PropertyInfo(alias="employeeIds")]

    employer_id: Annotated[str, PropertyInfo(alias="employerId")]

    metadata: Dict[str, object]
    """Optional arbitrary metadata (<=10KB when JSON stringified)"""

    priority: Literal["normal", "high"]
    """Order priority level"""

    provider_created: Annotated[bool, PropertyInfo(alias="providerCreated")]

    providers_ids: Annotated[Iterable[Variant0ProvidersID], PropertyInfo(alias="providersIds")]

    quantities: Dict[str, int]

    re_captcha_token: Annotated[str, PropertyInfo(alias="reCaptchaToken")]

    services_ids: Annotated[SequenceNotStr[str], PropertyInfo(alias="servicesIds")]

    token_id: Annotated[str, PropertyInfo(alias="tokenId")]


class Variant0Person(TypedDict, total=False):
    city: Required[str]

    dob: Required[str]
    """Date of birth in YYYY-MM-DD format"""

    email: Required[str]

    first_name: Required[Annotated[str, PropertyInfo(alias="firstName")]]

    last_name: Required[Annotated[str, PropertyInfo(alias="lastName")]]

    phone: Required[str]

    state: Required[str]

    street: Required[str]

    zipcode: Required[str]
    """US ZIP code in 12345 or 12345-6789 format"""

    country: str

    county: str

    street2: str


class Variant0Service(TypedDict, total=False):
    _id: Required[str]

    quantity: Required[int]

    auto_accept: Annotated[bool, PropertyInfo(alias="autoAccept")]


class Variant0ProvidersID(TypedDict, total=False):
    provider_id: Required[Annotated[str, PropertyInfo(alias="providerId")]]

    service_id: Annotated[str, PropertyInfo(alias="serviceId")]


class Variant1(TypedDict, total=False):
    employee_id: Required[Annotated[str, PropertyInfo(alias="employeeId")]]

    employer_id: Required[Annotated[str, PropertyInfo(alias="employerId")]]

    services: Required[Iterable[Variant1Service]]

    _id: str

    brand_id: Annotated[str, PropertyInfo(alias="brandId")]

    due_date: Annotated[Union[str, datetime], PropertyInfo(alias="dueDate", format="iso8601")]

    due_dates: Annotated[SequenceNotStr[Union[str, datetime]], PropertyInfo(alias="dueDates", format="iso8601")]

    employee_ids: Annotated[SequenceNotStr[str], PropertyInfo(alias="employeeIds")]

    metadata: Dict[str, object]
    """Optional arbitrary metadata (<=10KB when JSON stringified)"""

    payment_method: Annotated[Literal["self-pay", "employer-sponsored"], PropertyInfo(alias="paymentMethod")]

    person: Variant1Person

    priority: Literal["normal", "high"]
    """Order priority level"""

    provider_created: Annotated[bool, PropertyInfo(alias="providerCreated")]

    provider_id: Annotated[str, PropertyInfo(alias="providerId")]

    providers_ids: Annotated[Iterable[Variant1ProvidersID], PropertyInfo(alias="providersIds")]

    quantities: Dict[str, int]

    re_captcha_token: Annotated[str, PropertyInfo(alias="reCaptchaToken")]

    services_ids: Annotated[SequenceNotStr[str], PropertyInfo(alias="servicesIds")]

    token_id: Annotated[str, PropertyInfo(alias="tokenId")]


class Variant1Service(TypedDict, total=False):
    _id: Required[str]

    quantity: Required[int]

    auto_accept: Annotated[bool, PropertyInfo(alias="autoAccept")]


class Variant1Person(TypedDict, total=False):
    city: Required[str]

    dob: Required[str]
    """Date of birth in YYYY-MM-DD format"""

    email: Required[str]

    first_name: Required[Annotated[str, PropertyInfo(alias="firstName")]]

    last_name: Required[Annotated[str, PropertyInfo(alias="lastName")]]

    phone: Required[str]

    state: Required[str]

    street: Required[str]

    zipcode: Required[str]
    """US ZIP code in 12345 or 12345-6789 format"""

    country: str

    county: str

    street2: str


class Variant1ProvidersID(TypedDict, total=False):
    provider_id: Required[Annotated[str, PropertyInfo(alias="providerId")]]

    service_id: Annotated[str, PropertyInfo(alias="serviceId")]


class Variant2(TypedDict, total=False):
    employee_id: Required[Annotated[str, PropertyInfo(alias="employeeId")]]

    employer_id: Required[Annotated[str, PropertyInfo(alias="employerId")]]

    providers_ids: Required[Annotated[Iterable[Variant2ProvidersID], PropertyInfo(alias="providersIds")]]

    services_ids: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="servicesIds")]]

    _id: str

    brand_id: Annotated[str, PropertyInfo(alias="brandId")]

    due_date: Annotated[Union[str, datetime], PropertyInfo(alias="dueDate", format="iso8601")]

    due_dates: Annotated[SequenceNotStr[Union[str, datetime]], PropertyInfo(alias="dueDates", format="iso8601")]

    employee_ids: Annotated[SequenceNotStr[str], PropertyInfo(alias="employeeIds")]

    metadata: Dict[str, object]
    """Optional arbitrary metadata (<=10KB when JSON stringified)"""

    payment_method: Annotated[Literal["self-pay", "employer-sponsored"], PropertyInfo(alias="paymentMethod")]

    person: Variant2Person

    priority: Literal["normal", "high"]
    """Order priority level"""

    provider_created: Annotated[bool, PropertyInfo(alias="providerCreated")]

    provider_id: Annotated[str, PropertyInfo(alias="providerId")]

    quantities: Dict[str, int]

    re_captcha_token: Annotated[str, PropertyInfo(alias="reCaptchaToken")]

    services: Iterable[Variant2Service]

    token_id: Annotated[str, PropertyInfo(alias="tokenId")]


class Variant2ProvidersID(TypedDict, total=False):
    provider_id: Required[Annotated[str, PropertyInfo(alias="providerId")]]

    service_id: Annotated[str, PropertyInfo(alias="serviceId")]


class Variant2Person(TypedDict, total=False):
    city: Required[str]

    dob: Required[str]
    """Date of birth in YYYY-MM-DD format"""

    email: Required[str]

    first_name: Required[Annotated[str, PropertyInfo(alias="firstName")]]

    last_name: Required[Annotated[str, PropertyInfo(alias="lastName")]]

    phone: Required[str]

    state: Required[str]

    street: Required[str]

    zipcode: Required[str]
    """US ZIP code in 12345 or 12345-6789 format"""

    country: str

    county: str

    street2: str


class Variant2Service(TypedDict, total=False):
    _id: Required[str]

    quantity: Required[int]

    auto_accept: Annotated[bool, PropertyInfo(alias="autoAccept")]


class Variant3(TypedDict, total=False):
    employee_ids: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="employeeIds")]]

    employer_id: Required[Annotated[str, PropertyInfo(alias="employerId")]]

    providers_ids: Required[Annotated[Iterable[Variant3ProvidersID], PropertyInfo(alias="providersIds")]]

    services_ids: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="servicesIds")]]

    _id: str

    brand_id: Annotated[str, PropertyInfo(alias="brandId")]

    due_date: Annotated[Union[str, datetime], PropertyInfo(alias="dueDate", format="iso8601")]

    due_dates: Annotated[SequenceNotStr[Union[str, datetime]], PropertyInfo(alias="dueDates", format="iso8601")]

    employee_id: Annotated[str, PropertyInfo(alias="employeeId")]

    metadata: Dict[str, object]
    """Optional arbitrary metadata (<=10KB when JSON stringified)"""

    payment_method: Annotated[Literal["self-pay", "employer-sponsored"], PropertyInfo(alias="paymentMethod")]

    person: Variant3Person

    priority: Literal["normal", "high"]
    """Order priority level"""

    provider_created: Annotated[bool, PropertyInfo(alias="providerCreated")]

    provider_id: Annotated[str, PropertyInfo(alias="providerId")]

    quantities: Dict[str, int]

    re_captcha_token: Annotated[str, PropertyInfo(alias="reCaptchaToken")]

    services: Iterable[Variant3Service]

    token_id: Annotated[str, PropertyInfo(alias="tokenId")]


class Variant3ProvidersID(TypedDict, total=False):
    provider_id: Required[Annotated[str, PropertyInfo(alias="providerId")]]

    service_id: Annotated[str, PropertyInfo(alias="serviceId")]


class Variant3Person(TypedDict, total=False):
    city: Required[str]

    dob: Required[str]
    """Date of birth in YYYY-MM-DD format"""

    email: Required[str]

    first_name: Required[Annotated[str, PropertyInfo(alias="firstName")]]

    last_name: Required[Annotated[str, PropertyInfo(alias="lastName")]]

    phone: Required[str]

    state: Required[str]

    street: Required[str]

    zipcode: Required[str]
    """US ZIP code in 12345 or 12345-6789 format"""

    country: str

    county: str

    street2: str


class Variant3Service(TypedDict, total=False):
    _id: Required[str]

    quantity: Required[int]

    auto_accept: Annotated[bool, PropertyInfo(alias="autoAccept")]


OrderCreateParams: TypeAlias = Union[Variant0, Variant1, Variant2, Variant3]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from bluehive import BlueHive, AsyncBlueHive
from tests.utils import assert_matches_type
from bluehive.types import (
    EmployeeListResponse,
    EmployeeCreateResponse,
    EmployeeDeleteResponse,
    EmployeeUpdateResponse,
    EmployeeLinkUserResponse,
    EmployeeRetrieveResponse,
    EmployeeUnlinkUserResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestEmployees:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: BlueHive) -> None:
        employee = client.employees.create(
            email="dev@stainless.com",
            first_name="x",
            last_name="x",
        )
        assert_matches_type(EmployeeCreateResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: BlueHive) -> None:
        employee = client.employees.create(
            email="dev@stainless.com",
            first_name="x",
            last_name="x",
            active_account="Active",
            address={
                "city": "x",
                "postal_code": "x",
                "state": "x",
                "street1": "x",
                "country": "country",
                "county": "county",
                "street2": "street2",
            },
            blurb="blurb",
            departments=["string"],
            dob="7321-69-10",
            employer_id="employer_id",
            extended_fields=[
                {
                    "name": "x",
                    "value": "x",
                }
            ],
            phone=[
                {
                    "number": "x",
                    "type": "Cell",
                }
            ],
            title="title",
        )
        assert_matches_type(EmployeeCreateResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: BlueHive) -> None:
        response = client.employees.with_raw_response.create(
            email="dev@stainless.com",
            first_name="x",
            last_name="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = response.parse()
        assert_matches_type(EmployeeCreateResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: BlueHive) -> None:
        with client.employees.with_streaming_response.create(
            email="dev@stainless.com",
            first_name="x",
            last_name="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = response.parse()
            assert_matches_type(EmployeeCreateResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: BlueHive) -> None:
        employee = client.employees.retrieve(
            "employeeId",
        )
        assert_matches_type(EmployeeRetrieveResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: BlueHive) -> None:
        response = client.employees.with_raw_response.retrieve(
            "employeeId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = response.parse()
        assert_matches_type(EmployeeRetrieveResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: BlueHive) -> None:
        with client.employees.with_streaming_response.retrieve(
            "employeeId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = response.parse()
            assert_matches_type(EmployeeRetrieveResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employee_id` but received ''"):
            client.employees.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update(self, client: BlueHive) -> None:
        employee = client.employees.update(
            _id="x",
        )
        assert_matches_type(EmployeeUpdateResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: BlueHive) -> None:
        employee = client.employees.update(
            _id="x",
            active_account="Active",
            address={
                "city": "x",
                "postal_code": "x",
                "state": "x",
                "street1": "x",
                "country": "country",
                "county": "county",
                "street2": "street2",
            },
            blurb="blurb",
            departments=["string"],
            dob="7321-69-10",
            email="dev@stainless.com",
            employer_id="employer_id",
            extended_fields=[
                {
                    "name": "x",
                    "value": "x",
                }
            ],
            first_name="x",
            last_name="x",
            phone=[
                {
                    "number": "x",
                    "type": "Cell",
                }
            ],
            title="title",
        )
        assert_matches_type(EmployeeUpdateResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: BlueHive) -> None:
        response = client.employees.with_raw_response.update(
            _id="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = response.parse()
        assert_matches_type(EmployeeUpdateResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: BlueHive) -> None:
        with client.employees.with_streaming_response.update(
            _id="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = response.parse()
            assert_matches_type(EmployeeUpdateResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list(self, client: BlueHive) -> None:
        employee = client.employees.list(
            employer_id="employerId",
        )
        assert_matches_type(EmployeeListResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: BlueHive) -> None:
        employee = client.employees.list(
            employer_id="employerId",
            limit="269125115713",
            offset="269125115713",
        )
        assert_matches_type(EmployeeListResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: BlueHive) -> None:
        response = client.employees.with_raw_response.list(
            employer_id="employerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = response.parse()
        assert_matches_type(EmployeeListResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: BlueHive) -> None:
        with client.employees.with_streaming_response.list(
            employer_id="employerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = response.parse()
            assert_matches_type(EmployeeListResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete(self, client: BlueHive) -> None:
        employee = client.employees.delete(
            "employeeId",
        )
        assert_matches_type(EmployeeDeleteResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: BlueHive) -> None:
        response = client.employees.with_raw_response.delete(
            "employeeId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = response.parse()
        assert_matches_type(EmployeeDeleteResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: BlueHive) -> None:
        with client.employees.with_streaming_response.delete(
            "employeeId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = response.parse()
            assert_matches_type(EmployeeDeleteResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: BlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employee_id` but received ''"):
            client.employees.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_link_user(self, client: BlueHive) -> None:
        employee = client.employees.link_user(
            employee_id="x",
            user_id="x",
        )
        assert_matches_type(EmployeeLinkUserResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_link_user_with_all_params(self, client: BlueHive) -> None:
        employee = client.employees.link_user(
            employee_id="x",
            user_id="x",
            role=["string"],
        )
        assert_matches_type(EmployeeLinkUserResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_link_user(self, client: BlueHive) -> None:
        response = client.employees.with_raw_response.link_user(
            employee_id="x",
            user_id="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = response.parse()
        assert_matches_type(EmployeeLinkUserResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_link_user(self, client: BlueHive) -> None:
        with client.employees.with_streaming_response.link_user(
            employee_id="x",
            user_id="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = response.parse()
            assert_matches_type(EmployeeLinkUserResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_unlink_user(self, client: BlueHive) -> None:
        employee = client.employees.unlink_user(
            employee_id="employeeId",
            user_id="userId",
        )
        assert_matches_type(EmployeeUnlinkUserResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_unlink_user(self, client: BlueHive) -> None:
        response = client.employees.with_raw_response.unlink_user(
            employee_id="employeeId",
            user_id="userId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = response.parse()
        assert_matches_type(EmployeeUnlinkUserResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_unlink_user(self, client: BlueHive) -> None:
        with client.employees.with_streaming_response.unlink_user(
            employee_id="employeeId",
            user_id="userId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = response.parse()
            assert_matches_type(EmployeeUnlinkUserResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncEmployees:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncBlueHive) -> None:
        employee = await async_client.employees.create(
            email="dev@stainless.com",
            first_name="x",
            last_name="x",
        )
        assert_matches_type(EmployeeCreateResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncBlueHive) -> None:
        employee = await async_client.employees.create(
            email="dev@stainless.com",
            first_name="x",
            last_name="x",
            active_account="Active",
            address={
                "city": "x",
                "postal_code": "x",
                "state": "x",
                "street1": "x",
                "country": "country",
                "county": "county",
                "street2": "street2",
            },
            blurb="blurb",
            departments=["string"],
            dob="7321-69-10",
            employer_id="employer_id",
            extended_fields=[
                {
                    "name": "x",
                    "value": "x",
                }
            ],
            phone=[
                {
                    "number": "x",
                    "type": "Cell",
                }
            ],
            title="title",
        )
        assert_matches_type(EmployeeCreateResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employees.with_raw_response.create(
            email="dev@stainless.com",
            first_name="x",
            last_name="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = await response.parse()
        assert_matches_type(EmployeeCreateResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employees.with_streaming_response.create(
            email="dev@stainless.com",
            first_name="x",
            last_name="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = await response.parse()
            assert_matches_type(EmployeeCreateResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncBlueHive) -> None:
        employee = await async_client.employees.retrieve(
            "employeeId",
        )
        assert_matches_type(EmployeeRetrieveResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employees.with_raw_response.retrieve(
            "employeeId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = await response.parse()
        assert_matches_type(EmployeeRetrieveResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employees.with_streaming_response.retrieve(
            "employeeId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = await response.parse()
            assert_matches_type(EmployeeRetrieveResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employee_id` but received ''"):
            await async_client.employees.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncBlueHive) -> None:
        employee = await async_client.employees.update(
            _id="x",
        )
        assert_matches_type(EmployeeUpdateResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncBlueHive) -> None:
        employee = await async_client.employees.update(
            _id="x",
            active_account="Active",
            address={
                "city": "x",
                "postal_code": "x",
                "state": "x",
                "street1": "x",
                "country": "country",
                "county": "county",
                "street2": "street2",
            },
            blurb="blurb",
            departments=["string"],
            dob="7321-69-10",
            email="dev@stainless.com",
            employer_id="employer_id",
            extended_fields=[
                {
                    "name": "x",
                    "value": "x",
                }
            ],
            first_name="x",
            last_name="x",
            phone=[
                {
                    "number": "x",
                    "type": "Cell",
                }
            ],
            title="title",
        )
        assert_matches_type(EmployeeUpdateResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employees.with_raw_response.update(
            _id="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = await response.parse()
        assert_matches_type(EmployeeUpdateResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employees.with_streaming_response.update(
            _id="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = await response.parse()
            assert_matches_type(EmployeeUpdateResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncBlueHive) -> None:
        employee = await async_client.employees.list(
            employer_id="employerId",
        )
        assert_matches_type(EmployeeListResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncBlueHive) -> None:
        employee = await async_client.employees.list(
            employer_id="employerId",
            limit="269125115713",
            offset="269125115713",
        )
        assert_matches_type(EmployeeListResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employees.with_raw_response.list(
            employer_id="employerId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = await response.parse()
        assert_matches_type(EmployeeListResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employees.with_streaming_response.list(
            employer_id="employerId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = await response.parse()
            assert_matches_type(EmployeeListResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncBlueHive) -> None:
        employee = await async_client.employees.delete(
            "employeeId",
        )
        assert_matches_type(EmployeeDeleteResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employees.with_raw_response.delete(
            "employeeId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = await response.parse()
        assert_matches_type(EmployeeDeleteResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employees.with_streaming_response.delete(
            "employeeId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = await response.parse()
            assert_matches_type(EmployeeDeleteResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncBlueHive) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `employee_id` but received ''"):
            await async_client.employees.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_link_user(self, async_client: AsyncBlueHive) -> None:
        employee = await async_client.employees.link_user(
            employee_id="x",
            user_id="x",
        )
        assert_matches_type(EmployeeLinkUserResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_link_user_with_all_params(self, async_client: AsyncBlueHive) -> None:
        employee = await async_client.employees.link_user(
            employee_id="x",
            user_id="x",
            role=["string"],
        )
        assert_matches_type(EmployeeLinkUserResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_link_user(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employees.with_raw_response.link_user(
            employee_id="x",
            user_id="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = await response.parse()
        assert_matches_type(EmployeeLinkUserResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_link_user(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employees.with_streaming_response.link_user(
            employee_id="x",
            user_id="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = await response.parse()
            assert_matches_type(EmployeeLinkUserResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_unlink_user(self, async_client: AsyncBlueHive) -> None:
        employee = await async_client.employees.unlink_user(
            employee_id="employeeId",
            user_id="userId",
        )
        assert_matches_type(EmployeeUnlinkUserResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_unlink_user(self, async_client: AsyncBlueHive) -> None:
        response = await async_client.employees.with_raw_response.unlink_user(
            employee_id="employeeId",
            user_id="userId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        employee = await response.parse()
        assert_matches_type(EmployeeUnlinkUserResponse, employee, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_unlink_user(self, async_client: AsyncBlueHive) -> None:
        async with async_client.employees.with_streaming_response.unlink_user(
            employee_id="employeeId",
            user_id="userId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            employee = await response.parse()
            assert_matches_type(EmployeeUnlinkUserResponse, employee, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["EmployeeListParams"]


class EmployeeListParams(TypedDict, total=False):
    employer_id: Required[Annotated[str, PropertyInfo(alias="employerId")]]
    """ID of the employer to list employees for"""

    limit: str
    """Maximum number of employees to return (default: 50)"""

    offset: str
    """Number of employees to skip (default: 0)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import TYPE_CHECKING, Any, Mapping
from typing_extensions import Self, override

import httpx

from . import _exceptions
from ._qs import Querystring
from ._types import (
    Omit,
    Timeout,
    NotGiven,
    Transport,
    ProxiesTypes,
    RequestOptions,
    not_given,
)
from ._utils import is_given, get_async_library
from ._compat import cached_property
from ._version import __version__
from ._streaming import Stream as Stream, AsyncStream as AsyncStream
from ._exceptions import BlueHiveError, APIStatusError
from ._base_client import (
    DEFAULT_MAX_RETRIES,
    SyncAPIClient,
    AsyncAPIClient,
)

if TYPE_CHECKING:
    from .resources import fax, hl7, health, orders, version, database, employees, employers, providers, integrations
    from .resources.fax import FaxResource, AsyncFaxResource
    from .resources.hl7 import Hl7Resource, AsyncHl7Resource
    from .resources.health import HealthResource, AsyncHealthResource
    from .resources.orders import OrdersResource, AsyncOrdersResource
    from .resources.version import VersionResource, AsyncVersionResource
    from .resources.database import DatabaseResource, AsyncDatabaseResource
    from .resources.employees import EmployeesResource, AsyncEmployeesResource
    from .resources.providers import ProvidersResource, AsyncProvidersResource
    from .resources.integrations import IntegrationsResource, AsyncIntegrationsResource
    from .resources.employers.employers import EmployersResource, AsyncEmployersResource

__all__ = [
    "Timeout",
    "Transport",
    "ProxiesTypes",
    "RequestOptions",
    "BlueHive",
    "AsyncBlueHive",
    "Client",
    "AsyncClient",
]


class BlueHive(SyncAPIClient):
    # client options
    api_key: str

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#client) for more details.
        http_client: httpx.Client | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new synchronous BlueHive client instance.

        This automatically infers the `api_key` argument from the `BLUEHIVE_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("BLUEHIVE_API_KEY")
        if api_key is None:
            raise BlueHiveError(
                "The api_key client option must be set either by passing api_key to the client or by setting the BLUEHIVE_API_KEY environment variable"
            )
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("BLUE_HIVE_BASE_URL")
        if base_url is None:
            base_url = f"https://api.bluehive.com"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

    @cached_property
    def health(self) -> HealthResource:
        from .resources.health import HealthResource

        return HealthResource(self)

    @cached_property
    def version(self) -> VersionResource:
        from .resources.version import VersionResource

        return VersionResource(self)

    @cached_property
    def providers(self) -> ProvidersResource:
        from .resources.providers import ProvidersResource

        return ProvidersResource(self)

    @cached_property
    def database(self) -> DatabaseResource:
        from .resources.database import DatabaseResource

        return DatabaseResource(self)

    @cached_property
    def fax(self) -> FaxResource:
        from .resources.fax import FaxResource

        return FaxResource(self)

    @cached_property
    def employers(self) -> EmployersResource:
        from .resources.employers import EmployersResource

        return EmployersResource(self)

    @cached_property
    def hl7(self) -> Hl7Resource:
        from .resources.hl7 import Hl7Resource

        return Hl7Resource(self)

    @cached_property
    def orders(self) -> OrdersResource:
        from .resources.orders import OrdersResource

        return OrdersResource(self)

    @cached_property
    def employees(self) -> EmployeesResource:
        from .resources.employees import EmployeesResource

        return EmployeesResource(self)

    @cached_property
    def integrations(self) -> IntegrationsResource:
        from .resources.integrations import IntegrationsResource

        return IntegrationsResource(self)

    @cached_property
    def with_raw_response(self) -> BlueHiveWithRawResponse:
        return BlueHiveWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> BlueHiveWithStreamedResponse:
        return BlueHiveWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        return {"Authorization": api_key}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": "false",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        http_client: httpx.Client | None = None,
        max_retries: int | NotGiven = not_given,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class AsyncBlueHive(AsyncAPIClient):
    # client options
    api_key: str

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultAsyncHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#asyncclient) for more details.
        http_client: httpx.AsyncClient | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new async AsyncBlueHive client instance.

        This automatically infers the `api_key` argument from the `BLUEHIVE_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("BLUEHIVE_API_KEY")
        if api_key is None:
            raise BlueHiveError(
                "The api_key client option must be set either by passing api_key to the client or by setting the BLUEHIVE_API_KEY environment variable"
            )
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("BLUE_HIVE_BASE_URL")
        if base_url is None:
            base_url = f"https://api.bluehive.com"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

    @cached_property
    def health(self) -> AsyncHealthResource:
        from .resources.health import AsyncHealthResource

        return AsyncHealthResource(self)

    @cached_property
    def version(self) -> AsyncVersionResource:
        from .resources.version import AsyncVersionResource

        return AsyncVersionResource(self)

    @cached_property
    def providers(self) -> AsyncProvidersResource:
        from .resources.providers import AsyncProvidersResource

        return AsyncProvidersResource(self)

    @cached_property
    def database(self) -> AsyncDatabaseResource:
        from .resources.database import AsyncDatabaseResource

        return AsyncDatabaseResource(self)

    @cached_property
    def fax(self) -> AsyncFaxResource:
        from .resources.fax import AsyncFaxResource

        return AsyncFaxResource(self)

    @cached_property
    def employers(self) -> AsyncEmployersResource:
        from .resources.employers import AsyncEmployersResource

        return AsyncEmployersResource(self)

    @cached_property
    def hl7(self) -> AsyncHl7Resource:
        from .resources.hl7 import AsyncHl7Resource

        return AsyncHl7Resource(self)

    @cached_property
    def orders(self) -> AsyncOrdersResource:
        from .resources.orders import AsyncOrdersResource

        return AsyncOrdersResource(self)

    @cached_property
    def employees(self) -> AsyncEmployeesResource:
        from .resources.employees import AsyncEmployeesResource

        return AsyncEmployeesResource(self)

    @cached_property
    def integrations(self) -> AsyncIntegrationsResource:
        from .resources.integrations import AsyncIntegrationsResource

        return AsyncIntegrationsResource(self)

    @cached_property
    def with_raw_response(self) -> AsyncBlueHiveWithRawResponse:
        return AsyncBlueHiveWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncBlueHiveWithStreamedResponse:
        return AsyncBlueHiveWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="comma")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        api_key = self.api_key
        return {"Authorization": api_key}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": f"async:{get_async_library()}",
            **self._custom_headers,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        http_client: httpx.AsyncClient | None = None,
        max_retries: int | NotGiven = not_given,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class BlueHiveWithRawResponse:
    _client: BlueHive

    def __init__(self, client: BlueHive) -> None:
        self._client = client

    @cached_property
    def health(self) -> health.HealthResourceWithRawResponse:
        from .resources.health import HealthResourceWithRawResponse

        return HealthResourceWithRawResponse(self._client.health)

    @cached_property
    def version(self) -> version.VersionResourceWithRawResponse:
        from .resources.version import VersionResourceWithRawResponse

        return VersionResourceWithRawResponse(self._client.version)

    @cached_property
    def providers(self) -> providers.ProvidersResourceWithRawResponse:
        from .resources.providers import ProvidersResourceWithRawResponse

        return ProvidersResourceWithRawResponse(self._client.providers)

    @cached_property
    def database(self) -> database.DatabaseResourceWithRawResponse:
        from .resources.database import DatabaseResourceWithRawResponse

        return DatabaseResourceWithRawResponse(self._client.database)

    @cached_property
    def fax(self) -> fax.FaxResourceWithRawResponse:
        from .resources.fax import FaxResourceWithRawResponse

        return FaxResourceWithRawResponse(self._client.fax)

    @cached_property
    def employers(self) -> employers.EmployersResourceWithRawResponse:
        from .resources.employers import EmployersResourceWithRawResponse

        return EmployersResourceWithRawResponse(self._client.employers)

    @cached_property
    def hl7(self) -> hl7.Hl7ResourceWithRawResponse:
        from .resources.hl7 import Hl7ResourceWithRawResponse

        return Hl7ResourceWithRawResponse(self._client.hl7)

    @cached_property
    def orders(self) -> orders.OrdersResourceWithRawResponse:
        from .resources.orders import OrdersResourceWithRawResponse

        return OrdersResourceWithRawResponse(self._client.orders)

    @cached_property
    def employees(self) -> employees.EmployeesResourceWithRawResponse:
        from .resources.employees import EmployeesResourceWithRawResponse

        return EmployeesResourceWithRawResponse(self._client.employees)

    @cached_property
    def integrations(self) -> integrations.IntegrationsResourceWithRawResponse:
        from .resources.integrations import IntegrationsResourceWithRawResponse

        return IntegrationsResourceWithRawResponse(self._client.integrations)


class AsyncBlueHiveWithRawResponse:
    _client: AsyncBlueHive

    def __init__(self, client: AsyncBlueHive) -> None:
        self._client = client

    @cached_property
    def health(self) -> health.AsyncHealthResourceWithRawResponse:
        from .resources.health import AsyncHealthResourceWithRawResponse

        return AsyncHealthResourceWithRawResponse(self._client.health)

    @cached_property
    def version(self) -> version.AsyncVersionResourceWithRawResponse:
        from .resources.version import AsyncVersionResourceWithRawResponse

        return AsyncVersionResourceWithRawResponse(self._client.version)

    @cached_property
    def providers(self) -> providers.AsyncProvidersResourceWithRawResponse:
        from .resources.providers import AsyncProvidersResourceWithRawResponse

        return AsyncProvidersResourceWithRawResponse(self._client.providers)

    @cached_property
    def database(self) -> database.AsyncDatabaseResourceWithRawResponse:
        from .resources.database import AsyncDatabaseResourceWithRawResponse

        return AsyncDatabaseResourceWithRawResponse(self._client.database)

    @cached_property
    def fax(self) -> fax.AsyncFaxResourceWithRawResponse:
        from .resources.fax import AsyncFaxResourceWithRawResponse

        return AsyncFaxResourceWithRawResponse(self._client.fax)

    @cached_property
    def employers(self) -> employers.AsyncEmployersResourceWithRawResponse:
        from .resources.employers import AsyncEmployersResourceWithRawResponse

        return AsyncEmployersResourceWithRawResponse(self._client.employers)

    @cached_property
    def hl7(self) -> hl7.AsyncHl7ResourceWithRawResponse:
        from .resources.hl7 import AsyncHl7ResourceWithRawResponse

        return AsyncHl7ResourceWithRawResponse(self._client.hl7)

    @cached_property
    def orders(self) -> orders.AsyncOrdersResourceWithRawResponse:
        from .resources.orders import AsyncOrdersResourceWithRawResponse

        return AsyncOrdersResourceWithRawResponse(self._client.orders)

    @cached_property
    def employees(self) -> employees.AsyncEmployeesResourceWithRawResponse:
        from .resources.employees import AsyncEmployeesResourceWithRawResponse

        return AsyncEmployeesResourceWithRawResponse(self._client.employees)

    @cached_property
    def integrations(self) -> integrations.AsyncIntegrationsResourceWithRawResponse:
        from .resources.integrations import AsyncIntegrationsResourceWithRawResponse

        return AsyncIntegrationsResourceWithRawResponse(self._client.integrations)


class BlueHiveWithStreamedResponse:
    _client: BlueHive

    def __init__(self, client: BlueHive) -> None:
        self._client = client

    @cached_property
    def health(self) -> health.HealthResourceWithStreamingResponse:
        from .resources.health import HealthResourceWithStreamingResponse

        return HealthResourceWithStreamingResponse(self._client.health)

    @cached_property
    def version(self) -> version.VersionResourceWithStreamingResponse:
        from .resources.version import VersionResourceWithStreamingResponse

        return VersionResourceWithStreamingResponse(self._client.version)

    @cached_property
    def providers(self) -> providers.ProvidersResourceWithStreamingResponse:
        from .resources.providers import ProvidersResourceWithStreamingResponse

        return ProvidersResourceWithStreamingResponse(self._client.providers)

    @cached_property
    def database(self) -> database.DatabaseResourceWithStreamingResponse:
        from .resources.database import DatabaseResourceWithStreamingResponse

        return DatabaseResourceWithStreamingResponse(self._client.database)

    @cached_property
    def fax(self) -> fax.FaxResourceWithStreamingResponse:
        from .resources.fax import FaxResourceWithStreamingResponse

        return FaxResourceWithStreamingResponse(self._client.fax)

    @cached_property
    def employers(self) -> employers.EmployersResourceWithStreamingResponse:
        from .resources.employers import EmployersResourceWithStreamingResponse

        return EmployersResourceWithStreamingResponse(self._client.employers)

    @cached_property
    def hl7(self) -> hl7.Hl7ResourceWithStreamingResponse:
        from .resources.hl7 import Hl7ResourceWithStreamingResponse

        return Hl7ResourceWithStreamingResponse(self._client.hl7)

    @cached_property
    def orders(self) -> orders.OrdersResourceWithStreamingResponse:
        from .resources.orders import OrdersResourceWithStreamingResponse

        return OrdersResourceWithStreamingResponse(self._client.orders)

    @cached_property
    def employees(self) -> employees.EmployeesResourceWithStreamingResponse:
        from .resources.employees import EmployeesResourceWithStreamingResponse

        return EmployeesResourceWithStreamingResponse(self._client.employees)

    @cached_property
    def integrations(self) -> integrations.IntegrationsResourceWithStreamingResponse:
        from .resources.integrations import IntegrationsResourceWithStreamingResponse

        return IntegrationsResourceWithStreamingResponse(self._client.integrations)


class AsyncBlueHiveWithStreamedResponse:
    _client: AsyncBlueHive

    def __init__(self, client: AsyncBlueHive) -> None:
        self._client = client

    @cached_property
    def health(self) -> health.AsyncHealthResourceWithStreamingResponse:
        from .resources.health import AsyncHealthResourceWithStreamingResponse

        return AsyncHealthResourceWithStreamingResponse(self._client.health)

    @cached_property
    def version(self) -> version.AsyncVersionResourceWithStreamingResponse:
        from .resources.version import AsyncVersionResourceWithStreamingResponse

        return AsyncVersionResourceWithStreamingResponse(self._client.version)

    @cached_property
    def providers(self) -> providers.AsyncProvidersResourceWithStreamingResponse:
        from .resources.providers import AsyncProvidersResourceWithStreamingResponse

        return AsyncProvidersResourceWithStreamingResponse(self._client.providers)

    @cached_property
    def database(self) -> database.AsyncDatabaseResourceWithStreamingResponse:
        from .resources.database import AsyncDatabaseResourceWithStreamingResponse

        return AsyncDatabaseResourceWithStreamingResponse(self._client.database)

    @cached_property
    def fax(self) -> fax.AsyncFaxResourceWithStreamingResponse:
        from .resources.fax import AsyncFaxResourceWithStreamingResponse

        return AsyncFaxResourceWithStreamingResponse(self._client.fax)

    @cached_property
    def employers(self) -> employers.AsyncEmployersResourceWithStreamingResponse:
        from .resources.employers import AsyncEmployersResourceWithStreamingResponse

        return AsyncEmployersResourceWithStreamingResponse(self._client.employers)

    @cached_property
    def hl7(self) -> hl7.AsyncHl7ResourceWithStreamingResponse:
        from .resources.hl7 import AsyncHl7ResourceWithStreamingResponse

        return AsyncHl7ResourceWithStreamingResponse(self._client.hl7)

    @cached_property
    def orders(self) -> orders.AsyncOrdersResourceWithStreamingResponse:
        from .resources.orders import AsyncOrdersResourceWithStreamingResponse

        return AsyncOrdersResourceWithStreamingResponse(self._client.orders)

    @cached_property
    def employees(self) -> employees.AsyncEmployeesResourceWithStreamingResponse:
        from .resources.employees import AsyncEmployeesResourceWithStreamingResponse

        return AsyncEmployeesResourceWithStreamingResponse(self._client.employees)

    @cached_property
    def integrations(self) -> integrations.AsyncIntegrationsResourceWithStreamingResponse:
        from .resources.integrations import AsyncIntegrationsResourceWithStreamingResponse

        return AsyncIntegrationsResourceWithStreamingResponse(self._client.integrations)


Client = BlueHive

AsyncClient = AsyncBlueHive



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .._types import Body, Query, Headers, NotGiven, not_given
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.integration_list_response import IntegrationListResponse
from ..types.integration_check_active_response import IntegrationCheckActiveResponse

__all__ = ["IntegrationsResource", "AsyncIntegrationsResource"]


class IntegrationsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> IntegrationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return IntegrationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> IntegrationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return IntegrationsResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        x_brand_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IntegrationListResponse:
        """
        Returns the current brand integrations object keyed by integration name (empty
        object if none). Brand resolved via x-brand-id header.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-brand-id": x_brand_id, **(extra_headers or {})}
        return self._get(
            "/v1/integrations",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IntegrationListResponse,
        )

    def check_active(
        self,
        name: str,
        *,
        x_brand_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IntegrationCheckActiveResponse:
        """
        Returns true if the named integration is active for the given brand (brand
        resolved via x-brand-id header).

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not name:
            raise ValueError(f"Expected a non-empty value for `name` but received {name!r}")
        extra_headers = {"x-brand-id": x_brand_id, **(extra_headers or {})}
        return self._get(
            f"/v1/integrations/{name}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IntegrationCheckActiveResponse,
        )


class AsyncIntegrationsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncIntegrationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncIntegrationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncIntegrationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return AsyncIntegrationsResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        x_brand_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IntegrationListResponse:
        """
        Returns the current brand integrations object keyed by integration name (empty
        object if none). Brand resolved via x-brand-id header.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"x-brand-id": x_brand_id, **(extra_headers or {})}
        return await self._get(
            "/v1/integrations",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IntegrationListResponse,
        )

    async def check_active(
        self,
        name: str,
        *,
        x_brand_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IntegrationCheckActiveResponse:
        """
        Returns true if the named integration is active for the given brand (brand
        resolved via x-brand-id header).

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not name:
            raise ValueError(f"Expected a non-empty value for `name` but received {name!r}")
        extra_headers = {"x-brand-id": x_brand_id, **(extra_headers or {})}
        return await self._get(
            f"/v1/integrations/{name}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IntegrationCheckActiveResponse,
        )


class IntegrationsResourceWithRawResponse:
    def __init__(self, integrations: IntegrationsResource) -> None:
        self._integrations = integrations

        self.list = to_raw_response_wrapper(
            integrations.list,
        )
        self.check_active = to_raw_response_wrapper(
            integrations.check_active,
        )


class AsyncIntegrationsResourceWithRawResponse:
    def __init__(self, integrations: AsyncIntegrationsResource) -> None:
        self._integrations = integrations

        self.list = async_to_raw_response_wrapper(
            integrations.list,
        )
        self.check_active = async_to_raw_response_wrapper(
            integrations.check_active,
        )


class IntegrationsResourceWithStreamingResponse:
    def __init__(self, integrations: IntegrationsResource) -> None:
        self._integrations = integrations

        self.list = to_streamed_response_wrapper(
            integrations.list,
        )
        self.check_active = to_streamed_response_wrapper(
            integrations.check_active,
        )


class AsyncIntegrationsResourceWithStreamingResponse:
    def __init__(self, integrations: AsyncIntegrationsResource) -> None:
        self._integrations = integrations

        self.list = async_to_streamed_response_wrapper(
            integrations.list,
        )
        self.check_active = async_to_streamed_response_wrapper(
            integrations.check_active,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EmployeeListResponse", "Employee", "EmployeeAddress", "EmployeeExtendedField", "EmployeePhone"]


class EmployeeAddress(BaseModel):
    """Employee address"""

    city: str
    """City"""

    postal_code: str = FieldInfo(alias="postalCode")
    """Postal code"""

    state: str
    """State"""

    street1: str
    """Street address line 1"""

    country: Optional[str] = None
    """Country"""

    county: Optional[str] = None
    """County"""

    street2: Optional[str] = None
    """Street address line 2"""


class EmployeeExtendedField(BaseModel):
    name: str
    """Field name"""

    value: str
    """Field value"""


class EmployeePhone(BaseModel):
    number: str
    """Phone number"""

    type: Literal["Cell", "Home", "Work", "Other"]
    """Type of phone number"""


class Employee(BaseModel):
    """Employee details"""

    api_id: str = FieldInfo(alias="_id")
    """Unique identifier"""

    email: str
    """Email address"""

    employer_id: str
    """ID of associated employer"""

    first_name: str = FieldInfo(alias="firstName")
    """First name"""

    last_name: str = FieldInfo(alias="lastName")
    """Last name"""

    active_account: Optional[Literal["Active", "Inactive"]] = FieldInfo(alias="activeAccount", default=None)
    """Account status"""

    address: Optional[EmployeeAddress] = None
    """Employee address"""

    blurb: Optional[str] = None
    """Brief description or bio"""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Creation timestamp"""

    created_by: Optional[str] = FieldInfo(alias="createdBy", default=None)
    """ID of user who created the employee"""

    departments: Optional[List[str]] = None
    """List of department names"""

    dob: Optional[str] = None
    """Date of birth"""

    extended_fields: Optional[List[EmployeeExtendedField]] = FieldInfo(alias="extendedFields", default=None)
    """Additional custom fields"""

    phone: Optional[List[EmployeePhone]] = None
    """Contact phone numbers"""

    title: Optional[str] = None
    """Job title"""

    updated_at: Optional[datetime] = FieldInfo(alias="updatedAt", default=None)
    """Last update timestamp"""

    updated_by: Optional[str] = FieldInfo(alias="updatedBy", default=None)
    """ID of user who last updated the employee"""


class EmployeeListResponse(BaseModel):
    """Employees retrieved successfully"""

    employees: List[Employee]
    """List of employees"""

    message: str

    success: bool

    total: float
    """Total number of employees returned"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal

import httpx

from ..types import (
    employee_list_params,
    employee_create_params,
    employee_update_params,
    employee_link_user_params,
    employee_unlink_user_params,
)
from .._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.employee_list_response import EmployeeListResponse
from ..types.employee_create_response import EmployeeCreateResponse
from ..types.employee_delete_response import EmployeeDeleteResponse
from ..types.employee_update_response import EmployeeUpdateResponse
from ..types.employee_retrieve_response import EmployeeRetrieveResponse
from ..types.employee_link_user_response import EmployeeLinkUserResponse
from ..types.employee_unlink_user_response import EmployeeUnlinkUserResponse

__all__ = ["EmployeesResource", "AsyncEmployeesResource"]


class EmployeesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EmployeesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return EmployeesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EmployeesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return EmployeesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        email: str,
        first_name: str,
        last_name: str,
        active_account: Literal["Active", "Inactive"] | Omit = omit,
        address: employee_create_params.Address | Omit = omit,
        blurb: str | Omit = omit,
        departments: SequenceNotStr[str] | Omit = omit,
        dob: str | Omit = omit,
        employer_id: str | Omit = omit,
        extended_fields: Iterable[employee_create_params.ExtendedField] | Omit = omit,
        phone: Iterable[employee_create_params.Phone] | Omit = omit,
        title: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeCreateResponse:
        """
        Create a new employee in the system.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/employees",
            body=maybe_transform(
                {
                    "email": email,
                    "first_name": first_name,
                    "last_name": last_name,
                    "active_account": active_account,
                    "address": address,
                    "blurb": blurb,
                    "departments": departments,
                    "dob": dob,
                    "employer_id": employer_id,
                    "extended_fields": extended_fields,
                    "phone": phone,
                    "title": title,
                },
                employee_create_params.EmployeeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployeeCreateResponse,
        )

    def retrieve(
        self,
        employee_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeRetrieveResponse:
        """
        Retrieve an employee by their unique ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employee_id:
            raise ValueError(f"Expected a non-empty value for `employee_id` but received {employee_id!r}")
        return self._get(
            f"/v1/employees/{employee_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployeeRetrieveResponse,
        )

    def update(
        self,
        *,
        _id: str,
        active_account: Literal["Active", "Inactive"] | Omit = omit,
        address: employee_update_params.Address | Omit = omit,
        blurb: str | Omit = omit,
        departments: SequenceNotStr[str] | Omit = omit,
        dob: str | Omit = omit,
        email: str | Omit = omit,
        employer_id: str | Omit = omit,
        extended_fields: Iterable[employee_update_params.ExtendedField] | Omit = omit,
        first_name: str | Omit = omit,
        last_name: str | Omit = omit,
        phone: Iterable[employee_update_params.Phone] | Omit = omit,
        title: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeUpdateResponse:
        """
        Update an existing employee in the system.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._put(
            "/v1/employees",
            body=maybe_transform(
                {
                    "_id": _id,
                    "active_account": active_account,
                    "address": address,
                    "blurb": blurb,
                    "departments": departments,
                    "dob": dob,
                    "email": email,
                    "employer_id": employer_id,
                    "extended_fields": extended_fields,
                    "first_name": first_name,
                    "last_name": last_name,
                    "phone": phone,
                    "title": title,
                },
                employee_update_params.EmployeeUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployeeUpdateResponse,
        )

    def list(
        self,
        *,
        employer_id: str,
        limit: str | Omit = omit,
        offset: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeListResponse:
        """
        List all employees for a given employer with pagination.

        Args:
          employer_id: ID of the employer to list employees for

          limit: Maximum number of employees to return (default: 50)

          offset: Number of employees to skip (default: 0)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v1/employees",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "employer_id": employer_id,
                        "limit": limit,
                        "offset": offset,
                    },
                    employee_list_params.EmployeeListParams,
                ),
            ),
            cast_to=EmployeeListResponse,
        )

    def delete(
        self,
        employee_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeDeleteResponse:
        """Delete an employee from the system.

        Cannot delete employees with existing
        orders.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employee_id:
            raise ValueError(f"Expected a non-empty value for `employee_id` but received {employee_id!r}")
        return self._delete(
            f"/v1/employees/{employee_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployeeDeleteResponse,
        )

    def link_user(
        self,
        *,
        employee_id: str,
        user_id: str,
        role: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeLinkUserResponse:
        """
        Link an employee to a user account with specified roles

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/employees/link-user",
            body=maybe_transform(
                {
                    "employee_id": employee_id,
                    "user_id": user_id,
                    "role": role,
                },
                employee_link_user_params.EmployeeLinkUserParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployeeLinkUserResponse,
        )

    def unlink_user(
        self,
        *,
        employee_id: str,
        user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeUnlinkUserResponse:
        """
        Remove the link between an employee and a user account

        Args:
          employee_id: ID of the employee to unlink

          user_id: ID of the user to unlink from

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._delete(
            "/v1/employees/unlink-user",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "employee_id": employee_id,
                        "user_id": user_id,
                    },
                    employee_unlink_user_params.EmployeeUnlinkUserParams,
                ),
            ),
            cast_to=EmployeeUnlinkUserResponse,
        )


class AsyncEmployeesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEmployeesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncEmployeesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEmployeesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/bluehive-health/bluehive-sdk-python#with_streaming_response
        """
        return AsyncEmployeesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        email: str,
        first_name: str,
        last_name: str,
        active_account: Literal["Active", "Inactive"] | Omit = omit,
        address: employee_create_params.Address | Omit = omit,
        blurb: str | Omit = omit,
        departments: SequenceNotStr[str] | Omit = omit,
        dob: str | Omit = omit,
        employer_id: str | Omit = omit,
        extended_fields: Iterable[employee_create_params.ExtendedField] | Omit = omit,
        phone: Iterable[employee_create_params.Phone] | Omit = omit,
        title: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeCreateResponse:
        """
        Create a new employee in the system.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/employees",
            body=await async_maybe_transform(
                {
                    "email": email,
                    "first_name": first_name,
                    "last_name": last_name,
                    "active_account": active_account,
                    "address": address,
                    "blurb": blurb,
                    "departments": departments,
                    "dob": dob,
                    "employer_id": employer_id,
                    "extended_fields": extended_fields,
                    "phone": phone,
                    "title": title,
                },
                employee_create_params.EmployeeCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployeeCreateResponse,
        )

    async def retrieve(
        self,
        employee_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeRetrieveResponse:
        """
        Retrieve an employee by their unique ID.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employee_id:
            raise ValueError(f"Expected a non-empty value for `employee_id` but received {employee_id!r}")
        return await self._get(
            f"/v1/employees/{employee_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployeeRetrieveResponse,
        )

    async def update(
        self,
        *,
        _id: str,
        active_account: Literal["Active", "Inactive"] | Omit = omit,
        address: employee_update_params.Address | Omit = omit,
        blurb: str | Omit = omit,
        departments: SequenceNotStr[str] | Omit = omit,
        dob: str | Omit = omit,
        email: str | Omit = omit,
        employer_id: str | Omit = omit,
        extended_fields: Iterable[employee_update_params.ExtendedField] | Omit = omit,
        first_name: str | Omit = omit,
        last_name: str | Omit = omit,
        phone: Iterable[employee_update_params.Phone] | Omit = omit,
        title: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeUpdateResponse:
        """
        Update an existing employee in the system.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._put(
            "/v1/employees",
            body=await async_maybe_transform(
                {
                    "_id": _id,
                    "active_account": active_account,
                    "address": address,
                    "blurb": blurb,
                    "departments": departments,
                    "dob": dob,
                    "email": email,
                    "employer_id": employer_id,
                    "extended_fields": extended_fields,
                    "first_name": first_name,
                    "last_name": last_name,
                    "phone": phone,
                    "title": title,
                },
                employee_update_params.EmployeeUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployeeUpdateResponse,
        )

    async def list(
        self,
        *,
        employer_id: str,
        limit: str | Omit = omit,
        offset: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeListResponse:
        """
        List all employees for a given employer with pagination.

        Args:
          employer_id: ID of the employer to list employees for

          limit: Maximum number of employees to return (default: 50)

          offset: Number of employees to skip (default: 0)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v1/employees",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "employer_id": employer_id,
                        "limit": limit,
                        "offset": offset,
                    },
                    employee_list_params.EmployeeListParams,
                ),
            ),
            cast_to=EmployeeListResponse,
        )

    async def delete(
        self,
        employee_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeDeleteResponse:
        """Delete an employee from the system.

        Cannot delete employees with existing
        orders.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not employee_id:
            raise ValueError(f"Expected a non-empty value for `employee_id` but received {employee_id!r}")
        return await self._delete(
            f"/v1/employees/{employee_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployeeDeleteResponse,
        )

    async def link_user(
        self,
        *,
        employee_id: str,
        user_id: str,
        role: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeLinkUserResponse:
        """
        Link an employee to a user account with specified roles

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/employees/link-user",
            body=await async_maybe_transform(
                {
                    "employee_id": employee_id,
                    "user_id": user_id,
                    "role": role,
                },
                employee_link_user_params.EmployeeLinkUserParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EmployeeLinkUserResponse,
        )

    async def unlink_user(
        self,
        *,
        employee_id: str,
        user_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EmployeeUnlinkUserResponse:
        """
        Remove the link between an employee and a user account

        Args:
          employee_id: ID of the employee to unlink

          user_id: ID of the user to unlink from

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._delete(
            "/v1/employees/unlink-user",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "employee_id": employee_id,
                        "user_id": user_id,
                    },
                    employee_unlink_user_params.EmployeeUnlinkUserParams,
                ),
            ),
            cast_to=EmployeeUnlinkUserResponse,
        )


class EmployeesResourceWithRawResponse:
    def __init__(self, employees: EmployeesResource) -> None:
        self._employees = employees

        self.create = to_raw_response_wrapper(
            employees.create,
        )
        self.retrieve = to_raw_response_wrapper(
            employees.retrieve,
        )
        self.update = to_raw_response_wrapper(
            employees.update,
        )
        self.list = to_raw_response_wrapper(
            employees.list,
        )
        self.delete = to_raw_response_wrapper(
            employees.delete,
        )
        self.link_user = to_raw_response_wrapper(
            employees.link_user,
        )
        self.unlink_user = to_raw_response_wrapper(
            employees.unlink_user,
        )


class AsyncEmployeesResourceWithRawResponse:
    def __init__(self, employees: AsyncEmployeesResource) -> None:
        self._employees = employees

        self.create = async_to_raw_response_wrapper(
            employees.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            employees.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            employees.update,
        )
        self.list = async_to_raw_response_wrapper(
            employees.list,
        )
        self.delete = async_to_raw_response_wrapper(
            employees.delete,
        )
        self.link_user = async_to_raw_response_wrapper(
            employees.link_user,
        )
        self.unlink_user = async_to_raw_response_wrapper(
            employees.unlink_user,
        )


class EmployeesResourceWithStreamingResponse:
    def __init__(self, employees: EmployeesResource) -> None:
        self._employees = employees

        self.create = to_streamed_response_wrapper(
            employees.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            employees.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            employees.update,
        )
        self.list = to_streamed_response_wrapper(
            employees.list,
        )
        self.delete = to_streamed_response_wrapper(
            employees.delete,
        )
        self.link_user = to_streamed_response_wrapper(
            employees.link_user,
        )
        self.unlink_user = to_streamed_response_wrapper(
            employees.unlink_user,
        )


class AsyncEmployeesResourceWithStreamingResponse:
    def __init__(self, employees: AsyncEmployeesResource) -> None:
        self._employees = employees

        self.create = async_to_streamed_response_wrapper(
            employees.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            employees.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            employees.update,
        )
        self.list = async_to_streamed_response_wrapper(
            employees.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            employees.delete,
        )
        self.link_user = async_to_streamed_response_wrapper(
            employees.link_user,
        )
        self.unlink_user = async_to_streamed_response_wrapper(
            employees.unlink_user,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EmployeeCreateResponse"]


class EmployeeCreateResponse(BaseModel):
    """Employee created successfully"""

    employee_id: str = FieldInfo(alias="employeeId")
    """ID of the created employee"""

    message: str

    success: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["IntegrationListResponse", "Integrations"]


class Integrations(BaseModel):
    active: bool

    display_name: str = FieldInfo(alias="displayName")

    config: Optional[Dict[str, object]] = None


class IntegrationListResponse(BaseModel):
    integrations: Dict[str, Integrations]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .fax_send_params import FaxSendParams as FaxSendParams
from .fax_send_response import FaxSendResponse as FaxSendResponse
from .order_create_params import OrderCreateParams as OrderCreateParams
from .order_update_params import OrderUpdateParams as OrderUpdateParams
from .employee_list_params import EmployeeListParams as EmployeeListParams
from .health_check_response import HealthCheckResponse as HealthCheckResponse
from .order_create_response import OrderCreateResponse as OrderCreateResponse
from .order_update_response import OrderUpdateResponse as OrderUpdateResponse
from .employee_create_params import EmployeeCreateParams as EmployeeCreateParams
from .employee_list_response import EmployeeListResponse as EmployeeListResponse
from .employee_update_params import EmployeeUpdateParams as EmployeeUpdateParams
from .employer_create_params import EmployerCreateParams as EmployerCreateParams
from .employer_list_response import EmployerListResponse as EmployerListResponse
from .provider_lookup_params import ProviderLookupParams as ProviderLookupParams
from .hl7_send_results_params import Hl7SendResultsParams as Hl7SendResultsParams
from .order_retrieve_response import OrderRetrieveResponse as OrderRetrieveResponse
from .employee_create_response import EmployeeCreateResponse as EmployeeCreateResponse
from .employee_delete_response import EmployeeDeleteResponse as EmployeeDeleteResponse
from .employee_update_response import EmployeeUpdateResponse as EmployeeUpdateResponse
from .employer_create_response import EmployerCreateResponse as EmployerCreateResponse
from .provider_lookup_response import ProviderLookupResponse as ProviderLookupResponse
from .employee_link_user_params import EmployeeLinkUserParams as EmployeeLinkUserParams
from .hl7_send_results_response import Hl7SendResultsResponse as Hl7SendResultsResponse
from .integration_list_response import IntegrationListResponse as IntegrationListResponse
from .version_retrieve_response import VersionRetrieveResponse as VersionRetrieveResponse
from .employee_retrieve_response import EmployeeRetrieveResponse as EmployeeRetrieveResponse
from .employer_retrieve_response import EmployerRetrieveResponse as EmployerRetrieveResponse
from .order_update_status_params import OrderUpdateStatusParams as OrderUpdateStatusParams
from .employee_link_user_response import EmployeeLinkUserResponse as EmployeeLinkUserResponse
from .employee_unlink_user_params import EmployeeUnlinkUserParams as EmployeeUnlinkUserParams
from .fax_list_providers_response import FaxListProvidersResponse as FaxListProvidersResponse
from .order_upload_results_params import OrderUploadResultsParams as OrderUploadResultsParams
from .fax_retrieve_status_response import FaxRetrieveStatusResponse as FaxRetrieveStatusResponse
from .order_update_status_response import OrderUpdateStatusResponse as OrderUpdateStatusResponse
from .employee_unlink_user_response import EmployeeUnlinkUserResponse as EmployeeUnlinkUserResponse
from .order_retrieve_results_params import OrderRetrieveResultsParams as OrderRetrieveResultsParams
from .order_upload_results_response import OrderUploadResultsResponse as OrderUploadResultsResponse
from .database_check_health_response import DatabaseCheckHealthResponse as DatabaseCheckHealthResponse
from .order_send_for_employee_params import OrderSendForEmployeeParams as OrderSendForEmployeeParams
from .order_retrieve_results_response import OrderRetrieveResultsResponse as OrderRetrieveResultsResponse
from .order_send_for_employee_response import OrderSendForEmployeeResponse as OrderSendForEmployeeResponse
from .integration_check_active_response import IntegrationCheckActiveResponse as IntegrationCheckActiveResponse
from .order_schedule_appointment_params import OrderScheduleAppointmentParams as OrderScheduleAppointmentParams
from .order_schedule_appointment_response import OrderScheduleAppointmentResponse as OrderScheduleAppointmentResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["OrderSendForEmployeeParams", "ProvidersID"]


class OrderSendForEmployeeParams(TypedDict, total=False):
    employee_id: Required[Annotated[str, PropertyInfo(alias="employeeId")]]
    """Employee ID to send order to"""

    employer_id: Required[Annotated[str, PropertyInfo(alias="employerId")]]
    """Employer ID sending the order"""

    providers_ids: Required[Annotated[Iterable[ProvidersID], PropertyInfo(alias="providersIds")]]
    """Array mapping each service (by index) to a provider; serviceId optional"""

    services_ids: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="servicesIds")]]
    """Array of service IDs to include in the order"""

    login_token: Required[Annotated[str, PropertyInfo(alias="login-token")]]

    user_id: Required[Annotated[str, PropertyInfo(alias="user-id")]]

    brand_id: Annotated[str, PropertyInfo(alias="brandId")]
    """Brand ID for branded orders"""

    due_date: Annotated[str, PropertyInfo(alias="dueDate")]
    """Due date for the order (date or date-time ISO string)"""

    due_dates: Annotated[SequenceNotStr[str], PropertyInfo(alias="dueDates")]
    """Array of due dates per service"""

    metadata: Dict[str, object]
    """
    Optional arbitrary metadata to store on the order (non-indexed passthrough,
    <=10KB when JSON stringified)
    """

    priority: Literal["normal", "high"]
    """Order priority level"""

    provider_created: Annotated[bool, PropertyInfo(alias="providerCreated")]
    """Whether this order is being created by a provider (affects permission checking)"""

    provider_id: Annotated[str, PropertyInfo(alias="providerId")]
    """Single provider ID (shortcut when all services map to one provider)"""

    quantities: Dict[str, int]
    """Service ID to quantity mapping"""


class ProvidersID(TypedDict, total=False):
    provider_id: Required[Annotated[str, PropertyInfo(alias="providerId")]]

    service_id: Annotated[str, PropertyInfo(alias="serviceId")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .fax import (
    FaxResource,
    AsyncFaxResource,
    FaxResourceWithRawResponse,
    AsyncFaxResourceWithRawResponse,
    FaxResourceWithStreamingResponse,
    AsyncFaxResourceWithStreamingResponse,
)
from .hl7 import (
    Hl7Resource,
    AsyncHl7Resource,
    Hl7ResourceWithRawResponse,
    AsyncHl7ResourceWithRawResponse,
    Hl7ResourceWithStreamingResponse,
    AsyncHl7ResourceWithStreamingResponse,
)
from .health import (
    HealthResource,
    AsyncHealthResource,
    HealthResourceWithRawResponse,
    AsyncHealthResourceWithRawResponse,
    HealthResourceWithStreamingResponse,
    AsyncHealthResourceWithStreamingResponse,
)
from .orders import (
    OrdersResource,
    AsyncOrdersResource,
    OrdersResourceWithRawResponse,
    AsyncOrdersResourceWithRawResponse,
    OrdersResourceWithStreamingResponse,
    AsyncOrdersResourceWithStreamingResponse,
)
from .version import (
    VersionResource,
    AsyncVersionResource,
    VersionResourceWithRawResponse,
    AsyncVersionResourceWithRawResponse,
    VersionResourceWithStreamingResponse,
    AsyncVersionResourceWithStreamingResponse,
)
from .database import (
    DatabaseResource,
    AsyncDatabaseResource,
    DatabaseResourceWithRawResponse,
    AsyncDatabaseResourceWithRawResponse,
    DatabaseResourceWithStreamingResponse,
    AsyncDatabaseResourceWithStreamingResponse,
)
from .employees import (
    EmployeesResource,
    AsyncEmployeesResource,
    EmployeesResourceWithRawResponse,
    AsyncEmployeesResourceWithRawResponse,
    EmployeesResourceWithStreamingResponse,
    AsyncEmployeesResourceWithStreamingResponse,
)
from .employers import (
    EmployersResource,
    AsyncEmployersResource,
    EmployersResourceWithRawResponse,
    AsyncEmployersResourceWithRawResponse,
    EmployersResourceWithStreamingResponse,
    AsyncEmployersResourceWithStreamingResponse,
)
from .providers import (
    ProvidersResource,
    AsyncProvidersResource,
    ProvidersResourceWithRawResponse,
    AsyncProvidersResourceWithRawResponse,
    ProvidersResourceWithStreamingResponse,
    AsyncProvidersResourceWithStreamingResponse,
)
from .integrations import (
    IntegrationsResource,
    AsyncIntegrationsResource,
    IntegrationsResourceWithRawResponse,
    AsyncIntegrationsResourceWithRawResponse,
    IntegrationsResourceWithStreamingResponse,
    AsyncIntegrationsResourceWithStreamingResponse,
)

__all__ = [
    "HealthResource",
    "AsyncHealthResource",
    "HealthResourceWithRawResponse",
    "AsyncHealthResourceWithRawResponse",
    "HealthResourceWithStreamingResponse",
    "AsyncHealthResourceWithStreamingResponse",
    "VersionResource",
    "AsyncVersionResource",
    "VersionResourceWithRawResponse",
    "AsyncVersionResourceWithRawResponse",
    "VersionResourceWithStreamingResponse",
    "AsyncVersionResourceWithStreamingResponse",
    "ProvidersResource",
    "AsyncProvidersResource",
    "ProvidersResourceWithRawResponse",
    "AsyncProvidersResourceWithRawResponse",
    "ProvidersResourceWithStreamingResponse",
    "AsyncProvidersResourceWithStreamingResponse",
    "DatabaseResource",
    "AsyncDatabaseResource",
    "DatabaseResourceWithRawResponse",
    "AsyncDatabaseResourceWithRawResponse",
    "DatabaseResourceWithStreamingResponse",
    "AsyncDatabaseResourceWithStreamingResponse",
    "FaxResource",
    "AsyncFaxResource",
    "FaxResourceWithRawResponse",
    "AsyncFaxResourceWithRawResponse",
    "FaxResourceWithStreamingResponse",
    "AsyncFaxResourceWithStreamingResponse",
    "EmployersResource",
    "AsyncEmployersResource",
    "EmployersResourceWithRawResponse",
    "AsyncEmployersResourceWithRawResponse",
    "EmployersResourceWithStreamingResponse",
    "AsyncEmployersResourceWithStreamingResponse",
    "Hl7Resource",
    "AsyncHl7Resource",
    "Hl7ResourceWithRawResponse",
    "AsyncHl7ResourceWithRawResponse",
    "Hl7ResourceWithStreamingResponse",
    "AsyncHl7ResourceWithStreamingResponse",
    "OrdersResource",
    "AsyncOrdersResource",
    "OrdersResourceWithRawResponse",
    "AsyncOrdersResourceWithRawResponse",
    "OrdersResourceWithStreamingResponse",
    "AsyncOrdersResourceWithStreamingResponse",
    "EmployeesResource",
    "AsyncEmployeesResource",
    "EmployeesResourceWithRawResponse",
    "AsyncEmployeesResourceWithRawResponse",
    "EmployeesResourceWithStreamingResponse",
    "AsyncEmployeesResourceWithStreamingResponse",
    "IntegrationsResource",
    "AsyncIntegrationsResource",
    "IntegrationsResourceWithRawResponse",
    "AsyncIntegrationsResourceWithRawResponse",
    "IntegrationsResourceWithStreamingResponse",
    "AsyncIntegrationsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["OrderUpdateStatusParams"]


class OrderUpdateStatusParams(TypedDict, total=False):
    status: Required[
        Literal[
            "order_sent", "order_accepted", "order_refused", "employee_confirmed", "order_fulfilled", "order_complete"
        ]
    ]

    message: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = ["ServiceBundleCreateParams"]


class ServiceBundleCreateParams(TypedDict, total=False):
    bundle_name: Required[Annotated[str, PropertyInfo(alias="bundleName")]]

    service_ids: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="serviceIds")]]

    _id: str

    limit: float

    occurrence: str

    recurring: bool

    roles: Optional[SequenceNotStr[str]]

    start_date: Annotated[str, PropertyInfo(alias="startDate")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["OrderUpdateParams", "Service"]


class OrderUpdateParams(TypedDict, total=False):
    metadata: Dict[str, object]
    """
    Arbitrary metadata to update on the order (non-indexed passthrough, <=10KB when
    JSON stringified)
    """

    services: Iterable[Service]

    status: Literal[
        "order_sent", "order_accepted", "order_refused", "employee_confirmed", "order_fulfilled", "order_complete"
    ]


class Service(TypedDict, total=False):
    service_id: Required[Annotated[str, PropertyInfo(alias="serviceId")]]

    due_date: Annotated[Union[str, datetime], PropertyInfo(alias="dueDate", format="iso8601")]

    results: Dict[str, object]

    status: Literal["pending", "in_progress", "completed", "cancelled", "rejected"]



from __future__ import annotations

from typing import Any
from typing_extensions import override

from ._proxy import LazyProxy


class ResourcesProxy(LazyProxy[Any]):
    """A proxy for the `bluehive.resources` module.

    This is used so that we can lazily import `bluehive.resources` only when
    needed *and* so that users can just import `bluehive` and reference `bluehive.resources`
    """

    @override
    def __load__(self) -> Any:
        import importlib

        mod = importlib.import_module("bluehive.resources")
        return mod


resources = ResourcesProxy().__as_proxied__()



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["DatabaseCheckHealthResponse", "Stats"]


class Stats(BaseModel):
    """Database statistics (not available in production)"""

    collections: Optional[float] = None
    """Number of collections"""

    data_size: Optional[float] = FieldInfo(alias="dataSize", default=None)
    """Total data size in bytes"""

    documents: Optional[float] = None
    """Total number of documents"""


class DatabaseCheckHealthResponse(BaseModel):
    status: Literal["ok", "error"]
    """Database health status"""

    timestamp: str
    """Health check timestamp"""

    database: Optional[str] = None
    """Database name (hidden in production)"""

    error: Optional[str] = None
    """Error message if status is error"""

    stats: Optional[Stats] = None
    """Database statistics (not available in production)"""
